##  Guidelines and Best Practices
  * Keep it simple - SAP LeanIX is not a project management tool like Jira or monday.com. Add initiatives only up to level 2 or 3 (e.g., program/project/sub-project).
  * Consider out-of-the-box integrations, i.e., to Jira or other project portfolio management solutions.
  * Remove/update subtypes based on existing terminology.
  * Embed initiatives and the governance around them within your existing demand management, portfolio planning process, etc.
  * If your software development teams work in more traditional ways, you would typically use the fact sheet subtype programs or projects.
  * If your software development teams apply more agile ways of working, you would typically use the fact sheet subtype epic, but you might also use programs for larger transformation efforts.
